import express from 'express';
import multer from 'multer';
import fs from 'fs';
import path from 'path';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}
import db from './db.js'

const router = express.Router();

  // إعداد التخزين للصور
  const storage = multer.diskStorage({
    destination: (req, file, cb) => {
      cb(null, 'uploadsads/');
    },
    filename: (req, file, cb) => {
      const ext = path.extname(file.originalname);
      cb(null, `${Date.now()}-${uuidv4()}${ext}`);
    },
  });
  
  const upload = multer({ storage });

  
  // حذف إعلان
  router.delete('/delete/:id', async (req, res) => {
    const { id } = req.params;
  
    try {
      // جلب الصور المرتبطة بالإعلان من قاعدة البيانات
      const [rows] = await db.query('SELECT img1, img2, img3 FROM ads WHERE id = ?', [id]);
      const ad = rows[0];
  
      if (!ad) {
        return res.status(404).json({ message: 'الإعلان غير موجود.' });
      }
  
      // حذف الصور المرتبطة إذا كانت موجودة
      if (ad.img1) {
        const img1Path = path.join('uploadsads', ad.img1);
        if (fs.existsSync(img1Path)) {
          fs.unlinkSync(img1Path);
        }
      }
      if (ad.img2) {
        const img2Path = path.join('uploadsads', ad.img2);
        if (fs.existsSync(img2Path)) {
          fs.unlinkSync(img2Path);
        }
      }
      if (ad.img3) {
        const img3Path = path.join('uploadsads', ad.img3);
        if (fs.existsSync(img3Path)) {
          fs.unlinkSync(img3Path);
        }
      }
  
      // حذف الإعلان من قاعدة البيانات
      await db.query('DELETE FROM ads WHERE id = ?', [id]);
  
      res.json({ message: 'تم حذف الإعلان بنجاح!' });
    } catch (error) {
      res.status(500).json({ message: 'حدث خطأ أثناء حذف الإعلان.' });
    }
  });

export default router;