
import express from 'express';
import multer from 'multer';
  import fs from 'fs';
  import path from 'path';
  import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}
  import db from './db.js'

const router = express.Router();

// إعداد التخزين للصور
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsads/');
  },
  filename: (req, file, cb) => {
        const ext = path.extname(file.originalname);
        cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});
const upload = multer({ storage });

router.get('/', async (req, res) => {
    try {
     // console.log('Fetching all admins...');
      const [rows] = await db.query('SELECT * FROM ads');
      res.json(rows);
    } catch (error) {
      res.status(500).json({ message: 'حدث خطأ أثناء جلب المستخدمين.' });
    }
  });


  
  // تحديث إعلان
  router.put('/edit/:id', upload.fields([
    { name: 'img1', maxCount: 1 },
    { name: 'img2', maxCount: 1 },
    { name: 'img3', maxCount: 1 },
  ]), async (req, res) => {
    const { id } = req.params;
    const {
      adresads, textads, phoneadsid, useradsid, dateend, alaqsamid, alfroid, alfrooid, modelid, cash, areasid, citiesid, is_visible,
    } = req.body;
  
    try {
      // جلب الصور القديمة من قاعدة البيانات
      const [rows] = await db.query('SELECT img1, img2, img3 FROM ads WHERE id = ?', [id]);
      const oldImages = rows[0];
  
      const img1 = req.files?.img1?.[0]?.filename || oldImages.img1;
      const img2 = req.files?.img2?.[0]?.filename || oldImages.img2;
      const img3 = req.files?.img3?.[0]?.filename || oldImages.img3;
  
      // حذف الصور القديمة إذا تم استبدالها
      if (req.files?.img1?.[0]?.filename && oldImages.img1) {
        fs.unlinkSync(path.join('uploadsads', oldImages.img1));
      }
      if (req.files?.img2?.[0]?.filename && oldImages.img2) {
        fs.unlinkSync(path.join('uploadsads', oldImages.img2));
      }
      if (req.files?.img3?.[0]?.filename && oldImages.img3) {
        fs.unlinkSync(path.join('uploadsads', oldImages.img3));
      }
  
      // تحديث الإعلان في قاعدة البيانات
      const query = `
        UPDATE ads 
        SET adresads = ?, textads = ?, phoneadsid = ?, useradsid = ?, dateend = ?, alaqsamid = ?, alfroid = ?, alfrooid = ?, modelid = ?, 
            cash = ?, areasid = ?, citiesid = ?, is_visible = ?, img1 = ?, img2 = ?, img3 = ?
        WHERE id = ?
      `;
      const cashValue = cash === '' || cash === null ? null : parseFloat(cash) || null;
      const values = [
        adresads, textads, phoneadsid, useradsid, dateend, 
        alaqsamid, 
        alfroid || null, 
        alfrooid || null,
        modelid,
        cashValue, // القيمة المعدلة
        areasid,
        citiesid || null,
        is_visible, 
        img1, 
        img2, 
        img3, 
        id,
      ];
      
  
      await db.query(query, values);
  
      res.json({ message: 'تم تحديث الإعلان بنجاح!' });
    } catch (error) {
      res.status(500).json({ message: 'حدث خطأ أثناء تحديث الإعلان.' });
    }
  });
  

export default router;
