import express from 'express';
import multer from 'multer';
import bcrypt from 'bcrypt';
import verifyToken from './verifyToken.js';
import db from './db.js';
import fs from 'fs';
import path from 'path';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}

const router = express.Router();

const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsadmin/');
  },
  filename: (req, file, cb) => {
        const ext = path.extname(file.originalname);
        cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});

const upload = multer({ storage });

// تحديث بيانات المستخدم
router.put('/update', verifyToken, upload.single('image'), async (req, res) => {
  const userId = req.user.id; // معرف المستخدم من التوكن
  const { username, phone, password } = req.body;
  const newImage = req.file ? req.file.filename : null;

  try {
    // جلب بيانات المستخدم الحالية
    const [rows] = await db.execute('SELECT image FROM admins WHERE id = ?', [userId]);
    if (rows.length === 0) {
      return res.status(404).json({ message: 'المستخدم غير موجود' });
    }

    const oldImage = rows[0].image;

    // إذا كان هناك كلمة مرور جديدة، تشفيرها
    let hashedPassword = null;
    if (password) {
      hashedPassword = await bcrypt.hash(password, 10);
    }

    // بناء استعلام التحديث
    const updateFields = [];
    const updateValues = [];

    if (username) {
      updateFields.push('username = ?');
      updateValues.push(username);
    }
    if (phone) {
      updateFields.push('phone = ?');
      updateValues.push(phone);
    }
    if (hashedPassword) {
      updateFields.push('password = ?');
      updateValues.push(hashedPassword);
    }
    if (newImage) {
      updateFields.push('image = ?');
      updateValues.push(newImage);
    }

    updateValues.push(userId);

    const updateQuery = `
      UPDATE admins 
      SET ${updateFields.join(', ')}
      WHERE id = ?
    `;

    await db.execute(updateQuery, updateValues);

    // حذف الصورة القديمة إذا تم رفع صورة جديدة
    if (newImage && oldImage) {
      fs.unlink(`uploadsadmin/${oldImage}`, (err) => {
        if (err) {
        }
      });
    }

    res.json({ message: 'تم تحديث بيانات المستخدم بنجاح' });
  } catch (error) {
   // console.error('Error updating user:', error.message);
    res.status(500).json({ message: 'حدث خطأ أثناء تحديث بيانات المستخدم' });
  }
});

export default router;
