import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { useNavigate, } from 'react-router-dom';
import { getAuthDetails, /* logout */ } from '../authService';
import './AdminAds.css';

const AdminAds = ({ onAdAdded }) => {

    const navigate = useNavigate();
    const [userRole, setUserRole] = useState(null);
    
    useEffect(() => {
      const checkAuth = async () => {
        try {
          const authDetails = await getAuthDetails();
          if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
            navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
          } else {
            setUserRole(authDetails.role); // تعيين الدور
          }
        } catch (error) {
          console.error('Unauthorized:', error.message);
          navigate('/login'); // إعادة التوجيه عند حدوث خطأ
        }
      };
      checkAuth();
    }, [navigate]);
 
/*
    const handleLogout = async () => {
      try {
        await logout();
        navigate('/login');
      } catch (error) {
        console.error(error.message);
      }
    };
*/

    // الاعلان
  //  const [ads, setAds] = useState([]);
    const [formData, setFormData] = useState({
      adresads: '',
      textads: '',
      phoneadsid: '',
      useradsid: '',
      img1: null,
      img2: null,
      img3: null,
      dateend: '',
      alaqsamid: '',
      alfroid: '',
      alfrooid: '',
      modelid: '',
      cash: '',
      areasid: '',
      citiesid: '',
      is_visible: 1,
    });
    const [files, setFiles] = useState({ img1: null, img2: null, img3: null });
    const [foreignData, setForeignData] = useState({
      admins: [],
      alaqsam: [],
      alfro: [],
      alfroo: [],
      model: [],
      areas: [],
      cities: [],
    });
    const [filteredAlfro, setFilteredAlfro] = useState([]);
    const [filteredAlfroo, setFilteredAlfroo] = useState([]);
    const [filteredCities, setFilteredCities] = useState([]);
  
    useEffect(() => {
     // fetchAds();
      fetchForeignData();
    }, []);
 
    /*
    const fetchAds = async () => {
      try {
        const response = await axios.get('http://localhost:3001/api/adminads');
        setAds(response.data);
      } catch (error) {
        console.error('Error fetching ads:', error.message);
      }
    };
  */
    const fetchForeignData = async () => {
      try {
        const [admins, alaqsam, alfro, alfroo, model, areas, cities] = await Promise.all([
          axios.get('http://localhost:3001/api/admins'),
          axios.get('http://localhost:3001/api/alaqsam'),
          axios.get('http://localhost:3001/api/alfro'),
          axios.get('http://localhost:3001/api/alfroo'),
          axios.get('http://localhost:3001/api/modl'),
          axios.get('http://localhost:3001/api/areas'),
          axios.get('http://localhost:3001/api/cities'),
        ]);
  
        setForeignData({
          admins: admins.data,
          alaqsam: alaqsam.data,
          alfro: alfro.data,
          alfroo: alfroo.data,
          model: model.data,
          areas: areas.data,
          cities: cities.data,
        });
      } catch (error) {
        console.error('Error fetching foreign data:', error.message);
      }
    };



  
    const handleInputChange = (e) => {
      e.preventDefault()
      const { name, value } = e.target;
      setFormData((prev) => ({ ...prev, [name]: value }));
  
      if (name === 'alaqsamid') {
        const relatedAlfro = foreignData.alfro.filter((item) => item.alaqsam_id === parseInt(value));
        setFilteredAlfro(relatedAlfro);
        setFormData((prev) => ({ ...prev, alfroid: '', alfrooid: '' }));
        setFilteredAlfroo([]);
      }
  
      if (name === 'alfroid') {
        const relatedAlfroo = foreignData.alfroo.filter((item) => item.alfro_id === parseInt(value));
        setFilteredAlfroo(relatedAlfroo);
        setFormData((prev) => ({ ...prev, alfrooid: '' }));
      }
  
      if (name === 'areasid') {
        const relatedCities = foreignData.cities.filter((city) => city.areas_id === parseInt(value));
        setFilteredCities(relatedCities);
        setFormData((prev) => ({ ...prev, citiesid: '' }));
      }
  
      if (name === 'dateend') {
        const currentDate = new Date();
        const monthsToAdd = parseInt(value, 10);
        if (!isNaN(monthsToAdd)) {
          const calculatedDate = new Date(
            currentDate.getFullYear(),
            currentDate.getMonth() + monthsToAdd,
            currentDate.getDate()
          );
          setFormData((prev) => ({
            ...prev,
            dateend: calculatedDate.toISOString().split('T')[0],
          }));
        }
      }
    };

    const handleSubmit = async (e) => {
      e.preventDefault();
  
      const data = new FormData();
      for (const key in formData) {
        data.append(key, formData[key] || null);
      }
      for (const key in files) {
        if (files[key]) {
          data.append(key, files[key]);
        }
      }
  
      try {
        await axios.post('http://localhost:3001/api/adminads/add', data, {
          headers: { 'Content-Type': 'multipart/form-data' },
        });
        alert('تمت إضافة الإعلان بنجاح!');
       // navigate('/adminadsall');
       onAdAdded(); // الانتقال إلى صفحة "عرض الإعلانات"
      } catch (error) {
        console.error('Error adding ad:', error.response?.data || error.message);
        alert('حدث خطأ أثناء إضافة الإعلان.');
      }
    };
  
  
      const handleFileChange = (e) => {
        e.preventDefault()
        const { name, files } = e.target;
        setFiles((prev) => ({ ...prev, [name]: files[0] }));
      };
  

      
  /*
    const deleteAd = async (id) => {
      try {
        await axios.delete(`http://localhost:3001/api/adminads/delete/${id}`);
        fetchAds();
      } catch (error) {
        console.error('Error deleting ad:', error.message);
      }
    };
*/
  return (
    <div  className="admin-container">

              {userRole && <>
                    <h1>إدارة الإعلانات</h1>

                         {/* فورم إضافة إعلان جديد */}
      <div className="form-container">
        <h3>أضف إعلان جديد</h3>
        <form onSubmit={handleSubmit}>
        <input type="text" name="adresads" onChange={handleInputChange} placeholder="عنوان الإعلان" required />
        <textarea name="textads" onChange={handleInputChange} placeholder="وصف الإعلان" required></textarea>
        <select name="phoneadsid" onChange={handleInputChange} required>
          <option value="">اختر الهاتف</option>
          {foreignData.admins.map((admin) => (
            <option key={admin.id} value={admin.phone}>
              {admin.phone}
            </option>
          ))}
        </select>
        <select name="useradsid" onChange={handleInputChange} required>
          <option value="">اختر المستخدم</option>
          {foreignData.admins.map((admin) => (
            <option key={admin.id} value={admin.username}>
              {admin.username}
            </option>
          ))}
        </select>
        <select name="alaqsamid" onChange={handleInputChange} required>
          <option value="">اختر القسم</option>
          {foreignData.alaqsam.map((qsm) => (
            <option key={qsm.id} value={qsm.id}>
              {qsm.qsm}
            </option>
          ))}
        </select>
        {filteredAlfro.length > 0 && (
        <select name="alfroid" value={formData.alfroid} onChange={handleInputChange} required>
          <option value="">اختر الفرع الأول</option>
          {filteredAlfro.map((item) => (
            <option key={item.id} value={item.id}>
              {item.alfr1}
            </option>
          ))}
        </select>
      )}
      {filteredAlfroo.length > 0 && (
        <select name="alfrooid" value={formData.alfrooid} onChange={handleInputChange} required>
          <option value="">اختر الفرع الثاني</option>
          {filteredAlfroo.map((item) => (
            <option key={item.id} value={item.id}>
              {item.alfr2}
            </option>
          ))}
        </select>
      )}
      {formData.alaqsamid === '16' && (
        <select name="modelid" value={formData.modelid} onChange={handleInputChange}>
          <option value="">اختر الموديل</option>
          {foreignData.model.map((model) => (
            <option key={model.id} value={model.id}>
              {model.mdl}
            </option>
          ))}
        </select>
      )}
        <select name="areasid" onChange={handleInputChange} required>
          <option value="">اختر المنطقة</option>
          {foreignData.areas.map((area) => (
            <option key={area.id} value={area.id}>
              {area.area}
            </option>
          ))}
        </select>
        {filteredCities.length > 0 && (
        <select name="citiesid" value={formData.citiesid} onChange={handleInputChange} required>
          <option value="">اختر المدينة</option>
          {filteredCities.map((city) => (
            <option key={city.id} value={city.id}>
              {city.city}
            </option>
          ))}
        </select>
      )}
        <select name="dateend" onChange={handleInputChange} required>
          <option value="">اختر مدة الانتهاء</option>
          <option value="1">شهر</option>
          <option value="2">شهران</option>
          <option value="3">ثلاثة أشهر</option>
          <option value="6">ستة أشهر</option>
          <option value="12">سنة</option>
        </select>
        <input type="number" name="cash" onChange={handleInputChange} placeholder="السعر" required />
        <input type="file" name="img1" onChange={handleFileChange} required />
        <input type="file" name="img2" onChange={handleFileChange} />
        <input type="file" name="img3" onChange={handleFileChange} />
        <button type="submit">إضافة</button>
      </form>
      </div>

      {/* عرض الإعلانات */}
   {/*
    <ul>
        {ads.map((ad) => (
          <li key={ad.id}>
            {ad.adresads} - {ad.modelid}
            <button onClick={() => deleteAd(ad.id)}>حذف</button>
            {/* أزرار التعديل والتبديل }
          </li>
        ))}
      </ul>
   */}   

              </>}
    </div>
  );
};

export default AdminAds;
