import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails, /* logout */} from '../authService';
import axios from 'axios';
import './AdminAdsall.css'; // استيراد التنسيق


const AdminAdsall = ({ onViewDetails }) => {
  
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);

  // التوكن والكوكيز
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        console.error('Unauthorized:', error.message);
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

  /*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
      console.error(error.message);
    }
  };
  */

  // عرض الاعلانات
  const [ads, setAds] = useState([]);
    const [visibleAdsCount, setVisibleAdsCount] = useState(2); // عدد الإعلانات المرئية
    const adsPerPage = 2; // عدد الإعلانات لكل صفحة

  // جلب البيانات من قاعدة البيانات
  // جلب البيانات
  useEffect(() => {
    const fetchAds = async () => {
      const response = await axios.get('http://localhost:3001/api/adminadsall/all');
      setAds(response.data);
    };

    fetchAds();
  }, [ads]);

  // جلب البيانات من قاعدة البيانات
/*  useEffect(() => {
    const fetchAds = async () => {
      try {
        const response = await axios.get('http://localhost:3001/api/adminadsall/all');
        setAds(response.data);
      } catch (error) {
        console.error('Error fetching ads:', error.message);
      }
    };

    fetchAds();
  }, []);
*/

    // زر اظهار المزيد من الإعلانات المرئية فقط
    useEffect(() => {
      const fetchAds = async () => {
        try {
          const response = await axios.get("http://localhost:3001/api/public-ads");
          setAds(response.data);
        } catch (error) {
          console.error("Error fetching ads:", error.message);
        }
      };
  
      fetchAds();
    }, []);
    const visibleAds = ads.slice(0, visibleAdsCount);
    const handleLoadMore = () => {
      setVisibleAdsCount((prevCount) => prevCount + adsPerPage);
    };

  return (
    <div className='adminadsall'>
      {userRole && ( <>
          <h1 className="admin-ads-title">عرض الإعلانات</h1>


          { // ads عرض جميع الاعلانات
          visibleAds.length > 0 ? ( 
            <>
            <table className="admin-ads-table">
            {/* <thead>
                <tr>
                  <th>صورة الإعلان</th>
                  <th>عنوان الإعلان</th>
                  <th>المنطقة</th>
                  <th>المدينة</th>
                  <th>صاحب الاعلان</th>
                  <th>تاريخ الإعلان</th>
                </tr>
              </thead> */} 
              <tbody>
                { // ads عرض جميع الاعلانات
                
                visibleAds.map((ad) => (
                  <tr key={ad.id}>
                {/* صورة الإعلان */}
                <td className="ad-image">
                  {ad.img1 && (
                    <p onClick={() => onViewDetails(ad.id)}>
                      <img
                        src={`http://localhost:3001/uploadsads/${ad.img1}`}
                        alt="صورة الإعلان"
                        className="ad-thumbnail"
                      />
                    </p>
                  )}
                </td>                   
                {/* عنوان الإعلان */}
                <td className="ad-title">
                  <p onClick={() => onViewDetails(ad.id)} className="admin-ads-link">
                    {ad.adresads}
                  </p>
                </td>

                    <td>{ad.area || 'غير متوفرة'}</td>
                    <td>{ad.city || 'غير متوفرة'}</td>
                    <td>{ad.useradsid || 'غير متوفرة'}</td>
                    <td>{new Date(ad.datestart).toLocaleDateString('en-GB').replace(/\//g, '-')}</td>
                  </tr>
                ))}

              </tbody>
            </table>

            {/* زر إظهار المزيد */}
            {visibleAdsCount < ads.length && (
              <button className="load-more-button" onClick={handleLoadMore}>
                إظهار المزيد
              </button>
            )}   
            
          </>
          ) : (
            <p className="no-ads-message">لا توجد إعلانات لعرضها.</p>
          )}
        </>
      )}
      
    </div>
  );
};

export default AdminAdsall;