import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails, /* logout */ } from '../authService';
import axios from 'axios'
import './Fr1.css';

function Fr1() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

  /*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // الفرع الأول
  const [branches, setBranches] = useState([]);
  const [sections, setSections] = useState([]);
  const [newBranch, setNewBranch] = useState('');
  const [selectedSection, setSelectedSection] = useState('');
  const [editId, setEditId] = useState(null);
  const [editBranch, setEditBranch] = useState('');
  const [editSection, setEditSection] = useState('');

  // جلب الأقسام والفروع عند تحميل الصفحة
  useEffect(() => {
    fetchSections();
    fetchBranches();
  }, []);

  const fetchSections = async () => {
    try {
      const response = await axios.get('http://localhost:3001/api/alaqsam');
      setSections(response.data);
    } catch (error) {

    }
  };

  const fetchBranches = async () => {
    try {
      const response = await axios.get('http://localhost:3001/api/alfro');
      setBranches(response.data);
    } catch (error) {

    }
  };

  const addBranch = async (e) => {
    e.preventDefault();

    try {
      const response = await axios.post('http://localhost:3001/api/alfro/add', {
        alfr1: newBranch,
        alaqsam_id: selectedSection,
      });
      setBranches([
        ...branches,
        { id: response.data.id, alfr1: newBranch, alaqsam_id: selectedSection, qsm: sections.find(s => s.id === +selectedSection)?.qsm },
      ]);
      setNewBranch('');
      setSelectedSection('');
    } catch (error) {

    }
  };

  const deleteBranch = async (id) => {
    try {
      await axios.delete(`http://localhost:3001/api/alfro/delete/${id}`);
      setBranches(branches.filter((b) => b.id !== id));
    } catch (error) {

    }
  };

  const startEdit = (id, alfr1, alaqsam_id) => {
    setEditId(id);
    setEditBranch(alfr1);
    setEditSection(alaqsam_id);
  };

  const saveEdit = async () => {
    try {
      await axios.put(`http://localhost:3001/api/alfro/edit/${editId}`, {
        alfr1: editBranch,
        alaqsam_id: editSection,
      });
      setBranches(
        branches.map((b) =>
          b.id === editId ? { ...b, alfr1: editBranch, alaqsam_id: editSection, qsm: sections.find(s => s.id === +editSection)?.qsm } : b
        )
      );
      setEditId(null);
      setEditBranch('');
      setEditSection('');
    } catch (error) {

    }
  };

  const cancelEdit = () => {
    setEditId(null);
    setEditBranch('');
    setEditSection('');
  };

  return (
    <div className="fr1-container">

{userRole && <>
       <h1>أضف فرع جديد</h1>

             {/* فورم إضافة فرع جديد */}
      <form onSubmit={addBranch}>
        <input
          type="text"
          value={newBranch}
          onChange={(e) => setNewBranch(e.target.value)}
          placeholder="اسم الفرع"
          required
        />
        <select value={selectedSection} onChange={(e) => setSelectedSection(e.target.value)} required>
          <option value="">اختر القسم الرئيسي</option>
          {sections.map((section) => (
            <option key={section.id} value={section.id}>
              {section.qsm}
            </option>
          ))}
        </select>
        <button type="submit">إضافة فرع</button>
      </form>

      {/* قائمة الفروع */}
      <ul>
        {branches.map((branch) => (
          <li key={branch.id}>
            {editId === branch.id ? (
              <>
                <input
                  type="text"
                  value={editBranch}
                  onChange={(e) => setEditBranch(e.target.value)}
                />
                <select value={editSection} onChange={(e) => setEditSection(e.target.value)}>
                  {sections.map((section) => (
                    <option key={section.id} value={section.id}>
                      {section.qsm}
                    </option>
                  ))}
                </select>
                <button className='saveedit' onClick={saveEdit}>حفظ</button>
                <button onClick={cancelEdit}>تراجع</button>
              </>
            ) : (
              <>
                {branch.alfr1} (القسم: {branch.qsm})
                <button onClick={() => startEdit(branch.id, branch.alfr1, branch.alaqsam_id)}>تعديل</button>
                <button onClick={() => deleteBranch(branch.id)}>حذف</button>
              </>
            )}
          </li>
        ))}
      </ul>

      </>}
        
    </div>
  )
}

export default Fr1